# SPDX-FileCopyrightText: 2026 EasyUtilities contributors <https://github.com/easyscience>
# SPDX-License-Identifier: BSD-3-Clause


def test_dummy_fast():
    calculated = 2 + 2
    expected = 4
    assert calculated == expected
